# CHANGELOG

<!-- version list -->

## v1.0.2 (2025-12-01)

### Bug Fixes

- Working on fixing mcp-server
  ([`69ba291`](https://github.com/jupyter-naas/abi/commit/69ba291474a171da1652a8769493d35f3d2d3843))


## v1.0.1 (2025-12-01)

### Bug Fixes

- Working on api tests in CI/CD
  ([`5012a3b`](https://github.com/jupyter-naas/abi/commit/5012a3b4408f138d6e5c90a36c6f4d250f56af8a))


## v1.0.0 (2025-12-01)
## v1.0.0-dev.10 (2025-12-01)

### Bug Fixes

- Adding authors and removing uneeded configuration
  ([`c105454`](https://github.com/jupyter-naas/abi/commit/c105454bcb1ed1da88bda6ca23a05e9e3e9c1ed1))

- Configure release on main
  ([`fb32b93`](https://github.com/jupyter-naas/abi/commit/fb32b93ef0e3ce1b8bb291fda902a7a03c0f0646))


## v1.0.0-dev.9 (2025-11-30)

### Bug Fixes

- Working on api deployment
  ([`8a803ba`](https://github.com/jupyter-naas/abi/commit/8a803bad5db9ed9d020d18245b3b6fbafda6bb2c))


## v1.0.0-dev.8 (2025-11-30)


## v1.0.0-dev.7 (2025-11-30)


## v1.0.0-dev.6 (2025-11-30)


## v1.0.0-dev.5 (2025-11-30)

### Bug Fixes

- Working on ci/cd
  ([`d65250c`](https://github.com/jupyter-naas/abi/commit/d65250c10e433595a6ecd124c33aee9ca7e69535))


## v1.0.0-dev.4 (2025-11-30)

### Bug Fixes

- Working on ci
  ([`ba918da`](https://github.com/jupyter-naas/abi/commit/ba918da13147636ec732f2aba3e2978046b93970))


## v1.0.0-dev.3 (2025-11-30)

### Bug Fixes

- Uv install
  ([`c268208`](https://github.com/jupyter-naas/abi/commit/c268208bdcc69223fbb68114978211de7c161956))


## v1.0.0-dev.2 (2025-11-30)

### Bug Fixes

- Remove scoped prefix for semantic releases
  ([`c208c3f`](https://github.com/jupyter-naas/abi/commit/c208c3f12ad1cd2eb2264a166f0e683184efb2ca))


## v1.0.0-dev.1 (2025-11-30)

- Initial Release
